@@ -3,10 +3,8 @@ class filter_data:
         self.self=self
         '''In multiple filter function you can filter upto ten data 10 
         only you have to pass yor value as list(respect to multiple filter)'''
-    def filter_equalto_multiple(df,column,val):#val as list
-        print(len(val))
+    def filter_equalto_multiple(self,df,column,val):#val as list
         if type(val)==list and len(val)<=10:
-            print('start')
             if len(val)==2:
                 df=df.filter((col(column)==val[0])|(col(column)==val[1]))
             elif len(val)==3:
